summaryrefslogtreecommitdiffstats
path: root/testcases/functest_utils.py
diff options
context:
space:
mode:
Diffstat (limited to 'testcases/functest_utils.py')
-rw-r--r--testcases/functest_utils.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/testcases/functest_utils.py b/testcases/functest_utils.py
index 682c33ee3..0734ccbde 100644
--- a/testcases/functest_utils.py
+++ b/testcases/functest_utils.py
@@ -346,12 +346,12 @@ def update_cinder_quota(cinder_client, tenant_id, vols_quota, snapshots_quota,gi
return False
def get_private_net(neutron_client):
# Checks if there is an existing private network
networks = neutron_client.list_networks()['networks']
if len(networks) == 0:
return None
for net in networks:
- if net['router:external'] == False:
+ if (net['router:external'] == False) and (net['shared'] == True):
return net
return None
@@ -346,12 +346,12 @@ def update_cinder_quota(cinder_client, tenant_id, vols_quota, snapshots_quota,gi
return False
def get_private_net(neutron_client):
- # Checks if there is an existing private network
+ # Checks if there is an existing shared private network
networks = neutron_client.list_networks()['networks']
if len(networks) == 0: